---
layout: page
title: Frequently Asked Questions
permalink: /about/faq/
---

**How does CommunityRule relate to codes of conduct (like the [Contributor Covenant](https://www.contributor-covenant.org/)) or licesnses (like [Creative Commons](https://creativecommons.org/))?**

CommunityRule is focused on an often-missing component in online communities: the governance layer. Typically communities inherit the "[implicit feudalism](https://ntnsndr.in/implicit-feudalism)" of the underlying software, which usually centers around an all-powerful administrator. Codes of conduct, the implementation of them, and other features of the community rest on that underlying governance logic. Here is one way of picturing a community "stack":

![Stack: circulation & licensing, co-creation & collaboration, policies & culture, governance & processes, people & tech]({% link assets/communitystack.png %})

The purpose of CommunityRule is to make it easier for communities to efficiently replace the default feudalism with a more appropriate and accountable governance system, or Rule. Communities can then use their preferred Rule to fill in other layers of the stack through an explicit process.

**Why does focusing on the governance layer seem important? Haven't online communities gotten along fine so far?**

This project emerged out of a series of research projects. The first is called "[Admins, Mods, and Benevolent Dictators for Life: The Implicit Feudalism of Online Communities](https://osf.io/gxu3a/?view_only=11c9e93011df4865951f2056a64f5938)," and it traces the quiet persistence of surprisingly undemocratic tool-sets on platforms for online communities. This revealed that fostering democracy online tends to require extra work when compared to more feudal, non-democratic governance. Through the [Metagovernance Project](http://metagov.org/), this led to an ambitious proposal for software development, "[Modular Politics](https://ntnsndr.in/modular-politics)." CommunityRule is a more modest prototype, aiming to fill the gaps in online governance with a simple, natural-language toolkit in lieu of a more sophisticated software framework. 

**What's with the name "Rule"? Aren't these lists of multiple rules?**

The use of "Rule" in the singular is a tribute to the idiom used for the governance documents of medieval Latin monastic communities, which go by the name *Regula*. These are some of the oldest governing documents still in active use, and they serve the dual purposes of governance and spiritual guidance.

**What kinds of projects do you take inspiration from?**

A bunch of stuff, including but not limited to these:

* Codes of conduct
    - [Contributor Covenant](https://www.contributor-covenant.org/)
* Community toolkits
    - [Better Work Together](https://www.betterworktogether.co/)
    - [Prototyping Work](https://prototyping.work) (see [decision-making](https://prototyping.work/category/decision-making/) and [structure](https://prototyping.work/category/structure/)
    - [Sacred Design Lab](https://sacred.design/) on [covenants](https://mcusercontent.com/9ab8e3135a56f9b5acb9c04dd/files/b3eb53f3-9208-4f19-bd05-dae70d393c9c/Creating_Living_Small_Group_Covenant.pdf)
    - [Virtual Communities for Impact](https://communitiesforimpact.org/)
* Constitutions
    - [Constitute](https://www.constituteproject.org/)
* Example communities
    - [Loomio Community Group](https://loomio.coop/community_group.html)
    - [Social.coop bylaws](https://wiki.social.coop/rules-and-bylaws/Bylaws-for-social.coop.html)
* Incorporation tools
    - [One Click Orgs](https://web.archive.org/web/20190911090644/http://www.oneclickorgs.com/)
* Licensing tools
    - [Creative Commons](https://creativecommons.org/)
    - [License Zero](https://licensezero.com/)
    - [Polyform Project](https://polyformproject.org/)
* Monastic rules
    - Rule of St. Augustine
    - Rule of St. Benedict
    - Rule of St. Clare
    - [unMonastery BIOS](http://unmonastery.org/bios/)
* Software communities
    - [Apache](https://apache.org/foundation/governance/)
    - [Debian](https://www.debian.org/devel/constitution)
    - [Python](https://www.python.org/dev/peps/pep-8016/)
    - [Wikipedia](https://en.wikipedia.org/wiki/Wikipedia:Administration)


**What's the current project roadmap?**

Funny you mention it. Right here:

* Javascript output button
    - Could it output to IPFS or some other persisitent storage medium?
* Rules (ready-to-deploy presets)
    - Brand preset rules as CommunityRule rules with tools to create badges out of them
* Less textual, more visual header for Rule pages
* Further modularity
    - Aim for a logic of [progressive disclosure](https://en.wikipedia.org/wiki/Progressive_disclosure), making templates really simple but facilitating more complex iteration
    - In _modules, develop pseudocode primitives and complex modules with inputs, outputs, and actions
* Compatibility with Loomio?
    - Translate each module into Loomio practices, implicitly or explicitly (e.g., time for a proposal, threshold, voting options)
* Module system with database
    - JavaScript pulling from GDocs?
    - Use Jekyll yaml in _data/ to create modules
    - Jekyll csv data pull? https://jekyllrb.com/docs/datafiles/
